Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIFrameBufferQuartz2D.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIFrameBufferQuartz2D.cpp	(revision 43760)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIFrameBufferQuartz2D.cpp	(revision 43761)
@@ -435,13 +435,4 @@
     else
     {
-        /* Main (IDisplay) sending guest resize-event thinks that
-         * width and/or height can be zero (0) if this frame-buffer is hidden,
-         * we should just do a fallback to initial blackout
-         * frame-buffer of 640x480 size (like we are doing for QImage frame-buffer): */
-        if (m_width == 0 || m_height == 0)
-        {
-            m_width = 640;
-            m_height = 480;
-        }
         m_fUsesGuestVRAM = false;
         remind = true;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineView.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineView.cpp	(revision 43760)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineView.cpp	(revision 43761)
@@ -928,8 +928,9 @@
                    || pResizeEvent->height() != frameBuffer()->height();
 
-    /* Perform framebuffer resize: */
-    frameBuffer()->resizeEvent(pResizeEvent);
-
-    if (fResize)
+    /* Perform framebuffer resize if parent window is visible: */
+    if (uisession()->isScreenVisible(m_uScreenId))
+        frameBuffer()->resizeEvent(pResizeEvent);
+
+    if (fResize && uisession()->isScreenVisible(m_uScreenId))
     {
         /* Reapply maximum size restriction for machine-view: */
